@@ -216,13 +216,18 @@ def show_sets_filter(response):
             players = []
             for user in node['slots'][j]['entrant']['participants']:
                 cur_player = {}
-                cur_player['playerId'] = user['player']['id']
-                cur_player['playerTag'] = user['player']['gamerTag']
-                if user['entrants'] is not None:
-                    cur_player['entrantId'] = user['entrants'][0]['id']
+                if user['player'] is not None:
+                    cur_player['playerId'] = user['player']['id']
+                    cur_player['playerTag'] = user['player']['gamerTag']
+                    if user['entrants'] is not None:
+                        cur_player['entrantId'] = user['entrants'][0]['id']
+                    else:
+                        cur_player['entrantId'] = node['slots'][j]['entrant']['id']
+                    players.append(cur_player)
                 else:
+                    cur_player['playerId'] = None
+                    cur_player['playerTag'] = None
                     cur_player['entrantId'] = node['slots'][j]['entrant']['id']
-                players.append(cur_player)
             
             cur_set['entrant' + str(j+1) + 'Players'] = players
 
